==> activity-center-api-0.9.55-xhw-20190821.023542-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/SkinTemplateDataDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;

import java.util.List;

/**
 * ClassName: SkinTemplateDataDto <br/>
 * Function: 皮肤模板Dto. <br/>
 * date: 2017年2月24日 下午2:55:44 <br/>
 *
 * @author wubo
 * @version
 * @since JDK 1.7
 */
public class SkinTemplateDataDto extends BaseDto {

    private static final long serialVersionUID = 4927177308232082392L;

    private Long              id;                                     // 皮肤模板id
    private String            skinName;                               // 皮肤模板名称
    private Integer           templateType;                           // 皮肤模板类型
    private Integer           activityTemplateType;                   // 皮肤模板类型 区分自定义活动，直投页
    private Boolean           isDeleted;                              // 皮肤模板类型
    private String            skinType;                               // 模板标识
    private String            previewImg;                             // 预览图url
    private String            dataConfig;                             // 默认数据配置
    private String            styleConfig;                            // 默认样式配置
    private String            htmlConfig;                             // 活动自定义皮肤
    private Integer           newLayerRate;                           // 新弹层占比
    private Long              aLayerId;                               //a弹层id
    private Long              bLayerId;                               //b弹层id
    private String            aImage;                                 //a弹层预览图
    private String            bImage;                                 //b弹层预览图
    private Integer           isEnc;                                  //皮肤是否支持增值

    private List<SkinLayerDto> layerList;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getSkinName() {
        return skinName;
    }

    public void setSkinName(String skinName) {
        this.skinName = skinName;
    }

    public Integer getTemplateType() {
        return templateType;
    }

    public void setTemplateType(Integer templateType) {
        this.templateType = templateType;
    }

    public String getSkinType() {
        return skinType;
    }

    public void setSkinType(String skinType) {
        this.skinType = skinType;
    }

    public String getPreviewImg() {
        return previewImg;
    }

    public void setPreviewImg(String previewImg) {
        this.previewImg = previewImg;
    }

    public String getDataConfig() {
        return dataConfig;
    }

    public void setDataConfig(String dataConfig) {
        this.dataConfig = dataConfig;
    }

    public String getStyleConfig() {
        return styleConfig;
    }

    public void setStyleConfig(String styleConfig) {
        this.styleConfig = styleConfig;
    }

    public String getHtmlConfig() {
        return htmlConfig;
    }

    public void setHtmlConfig(String htmlConfig) {
        this.htmlConfig = htmlConfig;
    }

    public Integer getNewLayerRate() {
        return newLayerRate;
    }
    
    public void setNewLayerRate(Integer newLayerRate) {
        this.newLayerRate = newLayerRate;
    }

    public Long getaLayerId() {
        return aLayerId;
    }

    public void setaLayerId(Long aLayerId) {
        this.aLayerId = aLayerId;
    }

    public Long getbLayerId() {
        return bLayerId;
    }

    public void setbLayerId(Long bLayerId) {
        this.bLayerId = bLayerId;
    }

    public String getaImage() {
        return aImage;
    }

    public void setaImage(String aImage) {
        this.aImage = aImage;
    }

    public String getbImage() {
        return bImage;
    }

    public void setbImage(String bImage) {
        this.bImage = bImage;
    }

    public Boolean getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Boolean isDeleted) {
        this.isDeleted = isDeleted;
    }

    public Integer getIsEnc() {
        return isEnc;
    }

    public void setIsEnc(Integer isEnc) {
        this.isEnc = isEnc;
    }

    public List<SkinLayerDto> getLayerList() {
        return layerList;
    }

    public void setLayerList(List<SkinLayerDto> layerList) {
        this.layerList = layerList;
    }

    public Integer getActivityTemplateType() {
        return activityTemplateType;
    }

    public void setActivityTemplateType(Integer activityTemplateType) {
        this.activityTemplateType = activityTemplateType;
    }
}

==> activity-center-api-0.9.98-xhw2-20191107.092419-1-sources.jar: cn/com/duiba/tuia/activity/center/api/dto/SkinTemplateDataDto.java <==
package cn.com.duiba.tuia.activity.center.api.dto;

import cn.com.duiba.tuia.activity.center.api.common.BaseDto;

import java.util.List;

/**
 * ClassName: SkinTemplateDataDto <br/>
 * Function: 皮肤模板Dto. <br/>
 * date: 2017年2月24日 下午2:55:44 <br/>
 *
 * @author wubo
 * @version
 * @since JDK 1.7
 */
public class SkinTemplateDataDto extends BaseDto {

    private static final long serialVersionUID = 4927177308232082392L;

    private Long              id;                                     // 皮肤模板id
    private String            skinName;                               // 皮肤模板名称
    private Integer           templateType;                           // 皮肤模板类型
    private Integer           joinInType;                             // 接入类型
    private Integer           activityTemplateType;                   // 皮肤模板类型 区分自定义活动，直投页
    private Boolean           isDeleted;                              // 皮肤模板类型
    private String            skinType;                               // 模板标识
    private String            previewImg;                             // 预览图url
    private String            dataConfig;                             // 默认数据配置
    private String            styleConfig;                            // 默认样式配置
    private String            htmlConfig;                             // 活动自定义皮肤
    private Integer           newLayerRate;                           // 新弹层占比
    private Long              aLayerId;                               //a弹层id
    private Long              bLayerId;                               //b弹层id
    private String            aImage;                                 //a弹层预览图
    private String            bImage;                                 //b弹层预览图
    private Integer           isEnc;                                  //皮肤是否支持增值
    private Integer           isLayer;                                  //皮肤是否支持弹层

    private List<SkinLayerDto> layerList;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getSkinName() {
        return skinName;
    }

    public void setSkinName(String skinName) {
        this.skinName = skinName;
    }

    public Integer getTemplateType() {
        return templateType;
    }

    public void setTemplateType(Integer templateType) {
        this.templateType = templateType;
    }

    public String getSkinType() {
        return skinType;
    }

    public void setSkinType(String skinType) {
        this.skinType = skinType;
    }

    public String getPreviewImg() {
        return previewImg;
    }

    public void setPreviewImg(String previewImg) {
        this.previewImg = previewImg;
    }

    public String getDataConfig() {
        return dataConfig;
    }

    public void setDataConfig(String dataConfig) {
        this.dataConfig = dataConfig;
    }

    public String getStyleConfig() {
        return styleConfig;
    }

    public void setStyleConfig(String styleConfig) {
        this.styleConfig = styleConfig;
    }

    public String getHtmlConfig() {
        return htmlConfig;
    }

    public void setHtmlConfig(String htmlConfig) {
        this.htmlConfig = htmlConfig;
    }

    public Integer getNewLayerRate() {
        return newLayerRate;
    }
    
    public void setNewLayerRate(Integer newLayerRate) {
        this.newLayerRate = newLayerRate;
    }

    public Long getaLayerId() {
        return aLayerId;
    }

    public void setaLayerId(Long aLayerId) {
        this.aLayerId = aLayerId;
    }

    public Long getbLayerId() {
        return bLayerId;
    }

    public void setbLayerId(Long bLayerId) {
        this.bLayerId = bLayerId;
    }

    public String getaImage() {
        return aImage;
    }

    public void setaImage(String aImage) {
        this.aImage = aImage;
    }

    public String getbImage() {
        return bImage;
    }

    public void setbImage(String bImage) {
        this.bImage = bImage;
    }

    public Boolean getIsDeleted() {
        return isDeleted;
    }

    public void setIsDeleted(Boolean isDeleted) {
        this.isDeleted = isDeleted;
    }

    public Integer getIsEnc() {
        return isEnc;
    }

    public void setIsEnc(Integer isEnc) {
        this.isEnc = isEnc;
    }

    public List<SkinLayerDto> getLayerList() {
        return layerList;
    }

    public void setLayerList(List<SkinLayerDto> layerList) {
        this.layerList = layerList;
    }

    public Integer getActivityTemplateType() {
        return activityTemplateType;
    }

    public void setActivityTemplateType(Integer activityTemplateType) {
        this.activityTemplateType = activityTemplateType;
    }

    public Integer getJoinInType() {
        return joinInType;
    }

    public void setJoinInType(final Integer joinInType) {
        this.joinInType = joinInType;
    }

    public Integer getIsLayer() {
        return isLayer;
    }

    public void setIsLayer(Integer isLayer) {
        this.isLayer = isLayer;
    }
}
